@@ -2,39 +2,32 @@
 
 
 package HiD;
-{
-  $HiD::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::VERSION = '1.95_90';
 use Moose;
 use namespace::autoclean;
+# note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
-use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use Class::Load        qw/ :all /;
-use File::Basename;
+use Class::Load        qw/ try_load_class /;
+use DateTime;
 use File::Find::Rule;
-use File::Path         qw/ make_path /;
-use File::Remove       qw/ remove /;
+use Path::Tiny;
+use Try::Tiny;
+use YAML::Tiny;
+
 use HiD::File;
 use HiD::Layout;
 use HiD::Page;
+use HiD::Pager;
 use HiD::Post;
 use HiD::Types;
-use Module::Find;
-use Path::Class        qw/ file /;
-use Try::Tiny;
-use YAML::XS           qw/ LoadFile /;
 
 
 has categories => (
@@ -72,9 +65,7 @@ has config => (
   traits  => [ 'Hash' ] ,
   lazy    => 1 ,
   builder => '_build_config' ,
-  handles => {
-    get_config => 'get' ,
-  }
+  handles => { get_config => 'get' } ,
 );
 
 sub _build_config {
@@ -84,14 +75,14 @@ sub _build_config {
 
   if ( my $file = $self->config_file ) {
     try {
-      $config = LoadFile( $file ) // {};
+      $config = YAML::Tiny->read( $file )->[0] // {};
       ref $config eq 'HASH' or die $!;
       $config_loaded++;
     };
   }
 
   $config_loaded or $config = {}
-    and warn "WARNING: Could not read configuration. Using defaults (and options).\n";
+    and warn( "Could not read configuration. Using defaults (and options).\n" );
 
   return {
     %{ $self->default_config } ,
@@ -100,6 +91,9 @@ sub _build_config {
   };
 }
 
+# this is down here so it will see the 'get_config' delegation...
+with 'HiD::Role::DoesLogging';
+
 
 has config_file => (
   is      => 'ro' ,
@@ -113,12 +107,14 @@ has default_config => (
   traits   => [ 'Hash' ] ,
   init_arg => undef ,
   default  => sub{{
-    destination => '_site'    ,
-    include_dir => '_includes',
-    layout_dir  => '_layouts' ,
-    plugin_dir  => '_plugins' ,
-    posts_dir   => '_posts' ,
-    source      => '.' ,
+    default_author => 'your name here!' ,
+    destination    => '_site'    ,
+    include_dir    => '_includes',
+    layout_dir     => '_layouts' ,
+    plugin_dir     => '_plugins' ,
+    posts_dir      => '_posts' ,
+    drafts_dir     => '_drafts' ,
+    source         => '.' ,
   }},
 );
 
@@ -129,12 +125,19 @@ has destination => (
   lazy    => 1 ,
   default => sub {
     my $dest = shift->get_config( 'destination' );
-    make_path $dest unless -e -d $dest;
+    path( $dest )->mkpath() unless -e -d $dest;
     return $dest;
   },
 );
 
 
+has draft_post_file_regex => (
+  is      => 'ro' ,
+  isa     => 'RegexpRef' ,
+  default => sub { qr/^(?:.+?)\.(?:mk|mkd|mkdn|markdown|md|mmd|text|textile|html)$/ },
+);
+
+
 has excerpt_separator => (
   is  => 'ro' ,
   isa => 'Str' ,
@@ -189,6 +192,8 @@ has layouts => (
 sub _build_layouts {
   my $self = shift;
 
+  $self->INFO( "Building layouts" );
+
   my @layout_files = File::Find::Rule->file
     ->in( $self->layout_dir );
 
@@ -205,6 +210,8 @@ sub _build_layouts {
     });
 
     $self->add_input( $layout_file => 'layout' );
+
+    $self->DEBUG( "* Added layout $layout_file" );
   }
 
   foreach my $layout_name ( keys %layouts ) {
@@ -245,7 +252,7 @@ has objects => (
 has page_file_regex => (
   is      => 'ro' ,
   isa     => 'RegexpRef',
-  default => sub { qr/\.(mk|mkd|mkdn|markdown|textile|html|htm|xml|xhtml|xhtm|shtm|shtml|rss)$/ } ,
+  default => sub { qr/\.(mk|mkd|mkdn|markdown|mmd|textile|html|htm|xml|xhtml|xhtm|shtm|shtml|rss)$/ } ,
 );
 
 
@@ -262,6 +269,8 @@ sub _build_pages {
   # build posts before pages
   $self->posts;
 
+  $self->INFO( "Posts built." );
+
   my @potential_pages = File::Find::Rule->file->
     name( $self->page_file_regex )->in( '.' );
 
@@ -301,7 +310,7 @@ has plugin_dir => (
 
 has plugins => (
   is      => 'ro' ,
-  isa     => 'Maybe[ArrayRef[HiD::Plugin]]' ,
+  isa     => 'ArrayRef[Pluginish]' ,
   lazy    => 1 ,
   builder => '_build_plugins' ,
 );
@@ -309,41 +318,62 @@ has plugins => (
 sub _build_plugins {
   my $self = shift;
 
-  return undef unless $self->plugin_dir;
+  my @loaded_plugins;
 
-  # default plugin modules in HiD
-  my @def_mods = findallmod "Plugin";
+  if ( my $plugin_list = $self->config->{plugins} ){
+    my @plugins = ( ref $plugin_list eq 'ARRAY' ) ? @$plugin_list
+      : (split /\s+/ , $plugin_list );
 
-  # plugin modules in plugin_dir
-  setmoduledirs $self->plugin_dir;
-  my @mods = map { s/^\.:://r } findallmod ".";
+    foreach ( @plugins ) {
 
-  # load plugin modules
-  my @all_plugins;
-
-  push @INC , $self->plugin_dir;
-
-  foreach my $m ( @mods , @def_mods ) {
-    my( $lrlt , $lerr ) = try_load_class( $m );
-
-    warn "plugin $m cannot be loaded : $lerr \n" and next
-      unless $lrlt;
-
-    $m->isa('HiD::Plugin')
-      or warn "plugin $m is not a valid plugin. Plugins must inherit from HiD::Plugin\n"
-        and next;
-
-    push @all_plugins, $m;
+      my $plugin_name = ( /^\+/ ) ? $_ : "HiD::Generator::$_";
+      $self->INFO( "* Loading plugin $plugin_name" );
+      next unless _load_plugin_or_warn( $plugin_name );
+      push @loaded_plugins , $plugin_name->new;
+    }
   }
 
-  return @all_plugins ? \@all_plugins : undef;
+  if ( my $plugin_dir = $self->plugin_dir ) {
+    # plugin modules in plugin_dir
+    my @mods = File::Find::Rule->file->
+      name( '*.pm' )->in( $plugin_dir );
+
+    push @INC , $plugin_dir;
+
+    foreach my $m ( @mods ) {
+      $m =~ s|$plugin_dir/?||;
+      $m =~ s|.pm$||;
+      $self->INFO("* Loading plugin $m" );
+      next unless _load_plugin_or_warn( $m );
+      push @loaded_plugins, $m->new;
+    }
+  }
+
+  return \@loaded_plugins;
+}
+
+sub _load_plugin_or_warn {
+  my $plugin = shift;
+
+  my( $lrlt , $lerr ) = try_load_class( $plugin );
+
+  warn "plugin $plugin cannot be loaded : $lerr \n" and return undef
+    unless $lrlt;
+
+  ( $plugin->isa('HiD::Plugin') or
+    $plugin->does('HiD::Plugin') or
+    $plugin->does('HiD::Generator') )
+    or warn "plugin $plugin is not a valid plugin.\n"
+      and return undef;
+
+  return 1;
 }
 
 
 has post_file_regex => (
   is      => 'ro' ,
   isa     => 'RegexpRef' ,
-  default => sub { qr/^[0-9]{4}-[0-9]{1,2}-[0-9]{1,2}-(?:.+?)\.(?:mk|mkd|mkdn|markdown|md|text|textile|html)$/ },
+  default => sub { qr/^[0-9]{4}-[0-9]{1,2}-[0-9]{1,2}-(?:.+?)\.(?:mk|mkd|mkdn|markdown|md|mmd|text|textile|html)$/ },
 );
 
 
@@ -357,7 +387,9 @@ has posts_dir => (
 
 has posts => (
   is      => 'ro' ,
-  isa     => 'Maybe[ArrayRef[HiD::Post]]' ,
+  isa     => 'ArrayRef[HiD_Post]' ,
+  traits  => [ qw/ Array / ] ,
+  handles => { posts_size => 'count' } ,
   lazy    => 1 ,
   builder => '_build_posts' ,
 );
@@ -368,18 +400,27 @@ sub _build_posts {
   # build layouts before posts
   $self->layouts;
 
+  $self->INFO("Layouts built.");
+
+  $self->INFO("Building posts." );
+
   my $rule = File::Find::Rule->new;
 
   my @posts_directories = $rule->or(
-    $rule->new->directory->name( '_posts' ) ,
-      $rule->new->directory->name( '_site' )->prune->discard ,
+    $rule->new->directory->name( $self->get_config( 'posts_dir' )) ,
+    $rule->new->directory->name( $self->get_config( 'destination' ))->prune->discard ,
   )->in( $self->source );
 
   my @potential_posts = File::Find::Rule->file
     ->name( $self->post_file_regex )->in( @posts_directories );
 
+  if ( $self->get_config( 'publish_drafts' )){
+    push @potential_posts , $self->_build_potential_draft_posts_list ,
+  }
+
   my @posts = grep { $_ } map {
     try {
+      $self->DEBUG( "* Trying to build post $_" );
       my $post = HiD::Post->new({
         dest_dir       => $self->destination,
         hid            => $self ,
@@ -388,9 +429,10 @@ sub _build_posts {
       });
       $self->add_input( $_ => 'post' );
       $self->add_object( $post );
+      $self->DEBUG( "* Built post $_" );
       $post;
     }
-    catch { 0 };
+    catch { $self->ERROR( "ERROR: Post failed to build: $_" ) ; return 0 };
   } @potential_posts;
 
   @posts = sort { $b->date <=> $a->date } @posts;
@@ -403,6 +445,22 @@ sub _build_posts {
   return \@posts;
 }
 
+sub _build_potential_draft_posts_list {
+  my( $self ) = @_;
+
+  my $rule = File::Find::Rule->new;
+
+  my @posts_directories = $rule->or(
+    $rule->new->directory->name( $self->get_config( 'drafts_dir' )) ,
+    $rule->new->directory->name( $self->get_config( 'destination' ))->prune->discard ,
+  )->in( $self->source );
+
+  my @potential_posts = File::Find::Rule->file
+    ->name( $self->draft_post_file_regex )->in( @posts_directories );
+
+  return @potential_posts;
+}
+
 
 has processor => (
   is      => 'ro' ,
@@ -411,7 +469,7 @@ has processor => (
   default => sub {
     my $self = shift;
 
-    my $processor_name  = $self->get_config( 'processor_name' ) // 'Template';
+    my $processor_name  = $self->get_config( 'processor_name' ) // 'Handlebars';
 
     my $processor_class = ( $processor_name =~ /^\+/ ) ? $processor_name
       : "HiD::Processor::$processor_name";
@@ -430,16 +488,16 @@ has processor_args => (
   default => sub {
     my $self = shift;
 
-    return $self->get_config( 'processor_args' ) if
-      defined $self->get_config( 'processor_args' );
+    my $processor_args = defined $self->get_config('processor_args') ? $self->get_config('processor_args') : {};
 
-    my $include_path = $self->layout_dir;
-    $include_path   .= ':' . $self->include_dir
-      if defined $self->include_dir;
+    if(ref $processor_args eq 'HASH' && !exists $processor_args->{path}) {
+        my @path = ( $self->layout_dir );
+        push @path , $self->include_dir
+          if defined $self->include_dir;
+        $processor_args->{path} = \@path;
+    }
 
-    return {
-      INCLUDE_PATH => $include_path ,
-    };
+    return $processor_args;
   },
 );
 
@@ -457,6 +515,8 @@ sub _build_regular_files {
   # build pages before regular files
   $self->pages;
 
+  $self->INFO( "Pages built" );
+
   my @potential_files = File::Find::Rule->file->in( '.' );
 
   my @files = grep { $_ } map {
@@ -478,6 +538,20 @@ sub _build_regular_files {
 }
 
 
+has remove_unwritten_files => (
+  is => 'ro' ,
+  isa => 'Bool' ,
+  lazy => 1 ,
+  default => sub {
+    my $self = shift;
+    return $self->get_config('remove_unwritten_files')
+      if defined $self->get_config('remove_unwritten_files');
+
+    return 1;
+  },
+);
+
+
 has source => (
   is      => 'ro' ,
   isa     => 'HiD_DirPath' ,
@@ -511,6 +585,15 @@ sub _build_tags {
 }
 
 
+has time => (
+  is       => 'ro',
+  isa      => 'DateTime' ,
+  init_arg => undef ,
+  default  => sub { DateTime->now() } ,
+);
+
+
+
 has written_files => (
   is      => 'ro' ,
   isa     => 'HashRef' ,
@@ -527,33 +610,98 @@ has written_files => (
 sub publish {
   my( $self ) = @_;
 
-  # bootstrap data structures -- FIXME should have a more explicit way to do this
+  if ( -e $self->destination && $self->get_config( 'clean_destination' )){
+    my $path = path( $self->destination );
+    $path->remove_tree();
+    $self->INFO( "cleaned destination directory" );
+    $path->mkpath();
+  }
+
+  $self->INFO( "publish" );
+
+  # bootstrap data structures
+  # FIXME should have a more explicit way to do this
   $self->regular_files;
 
+  $self->INFO( "files bootstrapped" );
+
   $self->add_written_file( $self->destination => '_site_dir' );
 
+  $self->INFO( "processing plugins for generate()" );
+
+  foreach my $plugin ( @{ $self->plugins } ) {
+    if ( $plugin->does( 'HiD::Generator' )) {
+      $plugin->generate($self)
+    }
+  }
+
+  if ( $self->config->{pagination} ){
+    my $entries_per_page = $self->config->{pagination}{entries}
+      or die "Must set 'pagination.entries' key in pagination config";
+
+    my $page_fstring = $self->config->{pagination}{page}
+      or die "Must set 'pagination.page' key in pagination config";
+
+    my $template = $self->config->{pagination}{template}
+      or die "Must set 'pagination.template' key in pagination config";
+
+    my $pager = HiD::Pager->new({
+      entries             => $self->posts ,
+      entries_per_page    => $entries_per_page ,
+      hid                 => $self ,
+      page_pattern        => $page_fstring
+    });
+
+    while ( my $page_data = $pager->next ) {
+      my $page = HiD::Page->new({
+        dest_dir       => $self->destination ,
+        hid            => $self ,
+        input_filename => $template ,
+        layouts        => $self->layouts ,
+        url            => $page_data->{current_page_url} ,
+      });
+      $page->metadata->{page_data} = $page_data;
+
+      $self->add_input( "Paged page $page_data->{page_number}" => 'page' );
+      $self->add_object( $page );
+    }
+  }
+
+
   foreach my $file ( $self->all_objects ) {
     $file->publish;
 
-    my $path;
-    foreach my $part ( split '/' , $file->output_filename ) {
-      $path = file( $path , $part )->stringify;
-      $self->add_written_file( $path => 1 );
+    $self->INFO( sprintf "* Published %s" , $file->output_filename );
+
+    my $path = path( $file->output_filename );
+    while ( $path ne '.' ) {
+      $self->add_written_file( $path->stringify() => 1 );
+      $path = $path->parent;
     }
   }
 
-  foreach ( File::Find::Rule->in( $self->destination )) {
-    $self->wrote_file($_) or remove \1 , $_;
+  if ( $self->remove_unwritten_files ) {
+    foreach ( File::Find::Rule->in( $self->destination )) {
+      next if $self->wrote_file($_);
+
+      my $path = path( $_ );
+      $path->is_dir ? $path->remove_tree : $path->remove;
+    }
   }
 
-  # execute PLUGINS
   return 1 unless $self->plugins;
 
-  foreach my $p (@{$self->plugins}) {
-      $p->new->after_publish($self);
-  }
-  1;
+  $self->INFO( "processing plugins for after_publish()" );
 
+  foreach my $plugin ( @{ $self->plugins } ) {
+    if ( $plugin->does( 'HiD::Plugin' ) or
+         ### FIXME remove after 13 Nov 2014
+         $plugin->isa( 'HiD::Plugin'  )) {
+      $plugin->after_publish($self)
+    }
+  }
+
+  1;
 }
 
 
@@ -565,7 +713,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -612,6 +760,7 @@ Hashref of standard configuration options. The default config is:
     layout_dir  => '_layouts' ,
     plugin_dir  => '_plugins' ,
     posts_dir   => '_posts' ,
+    drafts_dir  => '_drafts' ,
     source      => '.' ,
 
 =head2 destination
@@ -620,6 +769,15 @@ Directory to write output files into.
 
 B<N.B.:> If it doesn't exist and is needed, it will be created.
 
+=head2 draft_post_file_regex
+
+Regular expression for which files will be recognized as draft blog posts.
+
+FIXME should this be configurable?
+
+FIXME this and post_file_regex should probably be built based on a common
+underlying "post_extensions_regex" attr...
+
 =head2 excerpt_separator
 
 String that distinguishes initial excerpt from "below the fold" content
@@ -669,7 +827,10 @@ Directory for plugins, which will be called after publish.
 
 =head2 plugins
 
-Plugins, called after publish.
+Plugins, which consume either of the L<HiD::Plugin> or L<HiD::Generator> roles.
+
+Plugins used to subclass L<HiD::Plugin>, but that behavior is deprecated and
+will be removed on or after 13 Nov 2014.
 
 =head2 post_file_regex
 
@@ -702,6 +863,15 @@ Defaults to appropriate Template Toolkit arguments.
 
 ArrayRef of L<HiD::File> objects, populated during processing.
 
+=head2 remove_unwritten_files ( Boolean )
+
+Boolean value controlling whether files found in the C<dest_dir> that weren't
+produced by HiD should be removed. In other words, when this is true, after a
+C<hid publish> run, only files produced by HiD will be found in the
+C<dest_dir>.
+
+Defaults to true.
+
 =head2 source
 
 Base directory that all other paths are calculated relative to.
@@ -710,6 +880,12 @@ Base directory that all other paths are calculated relative to.
 
 Tags hash, contains (tag, posts) pairs
 
+=head2 time
+
+DateTime object from the start of the latest run of the system.
+
+Cannot be set via argument.
+
 =head2 written_files
 
 Hashref of files written out during the publishing process.
@@ -810,7 +986,7 @@ L<StaticVolt>
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -818,7 +994,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
