@@ -2,25 +2,19 @@
 
 
 package HiD::App;
-{
-  $HiD::App::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::App::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::App::VERSION = '1.95_90';
 use Moose;
 extends 'MooseX::App::Cmd';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-sub default_command { 'publish' };
+sub default_command { 'help' };
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -29,7 +23,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -41,7 +35,7 @@ See C<perldoc hid> for usage information.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -49,7 +43,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
