@@ -2,23 +2,17 @@
 
 
 package HiD::App::Command;
-{
-  $HiD::App::Command::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::App::Command::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::App::Command::VERSION = '1.95_90';
 use Moose;
 extends 'MooseX::App::Cmd::Command';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use HiD;
 
@@ -32,12 +26,15 @@ has config_file => (
 );
 
 has hid => (
-  is       => 'ro' ,
-  isa      => 'HiD' ,
-  traits   => [ qw/ NoGetopt/ ] ,
-  init_arg => undef ,
-  writer   => '_set_hid' ,
-  handles  => [
+  is        => 'ro' ,
+  isa       => 'HiD' ,
+  lazy      => 1 ,
+  traits    => [ qw/ NoGetopt/ ] ,
+  init_arg  => undef ,
+  clearer   => '_clear_hid' ,
+  predicate => '_has_hid' ,
+  builder   => '_build_hid' ,
+  handles   => [
     'all_objects' ,
     'config' ,
     'destination' ,
@@ -45,7 +42,15 @@ has hid => (
   ] ,
 );
 
-sub _build_hid { return HiD->new }
+sub _build_hid { HiD->new( shift->hid_config ) }
+
+has hid_config => (
+  is       => 'ro' ,
+  isa      => 'HashRef' ,
+  traits   => [ qw/ NoGetopt / ] ,
+  init_arg => undef ,
+  writer   => '_set_hid_config' ,
+);
 
 sub execute {
   my( $self , $opts , $args ) = @_;
@@ -55,14 +60,28 @@ sub execute {
     exit;
   }
 
-  $self->_set_hid( HiD->new({
-    cli_opts    => $opts ,
-    config_file => $self->config_file ,
-  }));
+  my $hid_config = { cli_opts => $opts };
+  if ( $self->isa( 'HiD::App::Command::init')) {
+    $hid_config->{config} = {},
+  }
+  else {
+    $hid_config->{config_file} = $self->config_file
+  }
+
+  $self->_set_hid_config( $hid_config );
 
   $self->_run( $opts , $args );
 }
 
+
+sub reset_hid {
+  my( $self ) = @_;
+
+  $self->_clear_hid() if $self->_has_hid();
+
+  return $self->hid();
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -70,7 +89,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -104,9 +123,16 @@ Path to config file.
 
 Defaults to './_config.yml'
 
+=head1 METHODS
+
+=head2 reset_hid
+
+Clear out the existing L<HiD> object attribute, generate a fresh one with the
+stored configuration information, and return it.
+
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -114,7 +140,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
