@@ -2,23 +2,17 @@
 
 
 package HiD::App::Command::config;
-{
-  $HiD::App::Command::config::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::App::Command::config::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::App::Command::config::VERSION = '1.95_90';
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 sub _run {
   my( $self , $opts , $args ) = @_;
@@ -39,7 +33,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -73,7 +67,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -81,7 +75,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
