@@ -2,25 +2,19 @@
 
 
 package HiD::App::Command::init;
-{
-  $HiD::App::Command::init::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::App::Command::init::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::App::Command::init::VERSION = '1.95_90';
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use YAML::XS qw/ DumpFile /;
+use YAML::Tiny;
 
 
 has blog => (
@@ -55,7 +49,9 @@ sub _run {
 
   die "TODO: github support" if $self->github;
 
-  mkdir "_$_" for qw/ includes layouts site /;
+  for ( qw/ includes layouts site / ) {
+    mkdir "_$_" unless -e "_$_"
+  }
 
   open( my $fh , '>' , '_layouts/default.html' );
   print $fh <<EOF;
@@ -65,9 +61,8 @@ EOF
 
   $self->_init_blog if $self->blog;
 
-  DumpFile( '_config.yml' , {
-    title => $self->title ,
-  });
+  my $yaml = YAML::Tiny->new({ title => $self->title });
+  $yaml->write( '_config.yml' );
 
   say "Enjoy your new site!";
 }
@@ -105,7 +100,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -152,7 +147,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -160,7 +155,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
