@@ -2,17 +2,13 @@
 
 
 package HiD::App::Command::server;
-{
-  $HiD::App::Command::server::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::App::Command::server::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::App::Command::server::VERSION = '1.95_90';
 use Moose;
 extends 'HiD::App::Command';
+with 'HiD::Role::PublishesDrafts';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
@@ -20,10 +16,14 @@ use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 use feature     qw/ unicode_strings /;
 
-use namespace::autoclean;
-
+use Class::Load      qw/ try_load_class /;
+use Plack::Builder;
 use Plack::Runner;
 
+use HiD::Server;
+use HiD::Server::Handler;
+use HiD::Server::Loader;
+
 
 has auto_refresh => (
   is            => 'ro',
@@ -36,6 +36,22 @@ has auto_refresh => (
 );
 
 
+has clean => (
+  is          => 'ro' ,
+  isa         => 'Bool' ,
+  cmd_aliases => 'C' ,
+  traits      => [ 'Getopt' ] ,
+);
+
+
+has debug => (
+  is          => 'ro' ,
+  isa         => 'Bool' ,
+  cmd_aliases => 'D' ,
+  traits      => [ 'Getopt' ] ,
+);
+
+
 has port => (
   is            => 'ro' ,
   isa           => 'Int' ,
@@ -58,11 +74,33 @@ sub _build_port {
 sub _run {
   my( $self , $opts , $args ) = @_;
 
-  $self->publish;
+  my $config = $self->config;
+  if ( $self->clean ) {
+    $config->{clean_destination} = 1;
+  }
+
+  if ( $self->publish_drafts ){
+    $config->{publish_drafts} = 1;
+  }
 
   my $app = HiD::Server->new( root => $self->destination )->to_app;
 
-  my %args = ( -p => $self->port );
+  if ( $self->debug ) {
+    if ( try_load_class( 'Plack::Middleware::DebugLogging' )) {
+      $app = builder {
+        enable_if { $ENV{PLACK_ENV} eq 'development' } 'DebugLogging';
+        $app;
+      };
+    }
+    else {
+      print STDERR "*** Plack::Middleware::DebugLogging required for debug logging.\n";
+      print STDERR "*** Continuing with normal logging.\n";
+    }
+  }
+
+  my $runner = Plack::Runner->new;
+  my %args   = ( '-p' => $self->port );
+  $runner->parse_options(%args);
 
   # auto refresh
   if ( $self->auto_refresh ) {
@@ -72,54 +110,29 @@ sub _run {
       push @dirs, map { $_->input_filename } @{ $self->hid->$dir };
     }
 
-    $args{'-R'} = join ',', @dirs;
-    $args{'-r'} = 1;
+    # FIXME wish there was a better way to override stuff in Plack::Runner. >_<
+    $runner->{server} = '+HiD::Server::Handler';
+    $runner->{loader} = '+HiD::Server::Loader';
+    $runner->loader->watch(@dirs);
 
-    my $original_app = $app;
-    $app = \sub {
-      say 'Rebuild ... ';
-      $self->publish;
-      $original_app;
-    };
+    push @{$runner->{options}} , ( hid => $self );
+
+    # no need to explicitly ->publish() here, as that will happen inside
+    # HiD::Server::Loader, in the child, after the fork.
   }
+  else { $self->publish() }
 
-  my $runner = Plack::Runner->new;
-  $runner->parse_options(%args);
   $runner->run($app);
 }
 
 __PACKAGE__->meta->make_immutable;
-
-package # hide...
-  HiD::Server;
-
-use parent 'Plack::App::File';
-
-sub locate_file  {
-  my ($self, $env) = @_;
-
-  my $path = $env->{PATH_INFO} || '';
-
-  $path =~ s|^/|| unless $path eq '/';
-
-  if ( -e -d $path and $path !~ m|/$| ) {
-    $path .= '/';
-    $env->{PATH_INFO} .= '/';
-  }
-
-  $env->{PATH_INFO} .= 'index.html'
-    if ( $path && $path =~ m|/$| );
-
-  return $self->SUPER::locate_file( $env );
-}
-
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -140,6 +153,17 @@ Start a Plack-based web server that serves your C<destination> directory.
 
 Automatically refresh result when source file/dir changed, just likey jekyll
 
+Note that setting this will also clean out the destination directory whenever
+a watched file changes.
+
+=head2 clean
+
+Remove any existing site directory prior to the publication run
+
+=head2 debug
+
+Emit debug-style logging for requests
+
 =head2 port
 
 Port number to bind. Defaults to 5000.
@@ -151,7 +175,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -159,7 +183,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
