@@ -2,43 +2,45 @@
 
 
 package HiD::File;
-{
-  $HiD::File::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::File::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::File::VERSION = '1.95_90';
 use Moose;
 with 'HiD::Role::IsPublished';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename         qw/ fileparse /;
-use File::Copy::Recursive  qw/ fcopy /;
-use File::Path             qw/ make_path /;
-use Path::Class            qw/ file / ;
+use Path::Tiny;
 
 
 sub publish {
   my $self = shift;
 
-  my( undef , $dir ) = fileparse( $self->output_filename );
+  my $out = path( $self->output_filename );
+  my $dir = $out->parent;
 
-  make_path $dir unless -d $dir;
+  $dir->mkpath unless $dir->is_dir;
 
-  fcopy( $self->input_filename , $self->output_filename )
+  path( $self->input_filename )->copy( $out )
     or die $!;
 }
 
 # used to populate the 'url' attr in Role::IsPublished
-sub _build_url { return shift->input_filename }
+sub _build_url {
+  my $self = shift;
+
+  my $source = $self->source;
+
+  my $path_frag = $self->input_filename;
+  $path_frag =~ s/^$source//;
+
+  return path( $path_frag )->stringify;
+}
+
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -47,7 +49,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -78,7 +80,7 @@ well if you're trying to figure out how an object from this class works.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -86,7 +88,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
