@@ -2,27 +2,21 @@
 
 
 package HiD::Layout;
-{
-  $HiD::Layout::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Layout::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::Layout::VERSION = '1.95_90';
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use Encode;
-use File::Slurp qw/ read_file / ;
+use Path::Tiny;
+use YAML::Tiny  qw/ Load /;
+
 use HiD::Types;
-use YAML::XS;
 
 
 has content => (
@@ -86,14 +80,14 @@ sub BUILDARGS {
     ( $args{name} , $args{ext} ) = $args{filename}
       =~ m|^.*/(.+)\.([^.]+)$|;
 
-    my $content  = read_file( $args{filename}, binmode => ':utf8' );
+    my $content  = path( $args{filename} )->slurp_utf8;
     my $metadata = {};
 
     if ( $content =~ /^---\n/s ) {
       my $meta;
       ( $meta , $content ) = ( $content )
         =~ m|^---\n(.*?)---\n(.*)$|s;
-      $metadata = Load( encode('utf8', $meta) ) if $meta;
+      $metadata = Load( $meta ) if $meta;
     }
 
     $args{metadata} = $metadata;
@@ -148,7 +142,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -208,7 +202,7 @@ Will recurse into embedded layouts as needed.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -216,7 +210,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
