@@ -2,22 +2,16 @@
 
 
 package HiD::Plugin;
-{
-  $HiD::Plugin::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Plugin::AUTHORITY = 'cpan:GENEHACK';
-}
-
+$HiD::Plugin::VERSION = '1.95_90';
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
-use feature    qw/ unicode_strings /;
+
 
 sub after_publish { 1 }
 
@@ -27,7 +21,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -42,9 +36,13 @@ HiD::Plugin - Base class for plugins
 
 Base class for plugin object
 
+=head1 METHODS
+
+=head2 after_publish
+
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -52,7 +50,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
