@@ -2,29 +2,25 @@
 
 
 package HiD::Post;
-{
-  $HiD::Post::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Post::AUTHORITY = 'cpan:GENEHACK';
-}
-
+$HiD::Post::VERSION = '1.95_90';
 use Moose;
-with 'HiD::Role::IsConverted';
-with 'HiD::Role::IsPost';
-with 'HiD::Role::IsPublished';
+with
+  'HiD::Role::IsConverted',
+  'HiD::Role::IsPost',
+  'HiD::Role::IsPublished';
+with 'HiD::Role::DoesLogging'; # this one last b/c it needs method delegated
+                               # by initial roles
+
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename  qw/ fileparse /;
-use File::Path      qw/ make_path /;
+use Path::Tiny;
 use String::Errf    qw/ errf /;
 
 
@@ -33,8 +29,9 @@ sub BUILD {
 
   if ( defined $self->get_metadata('published')
          and not $self->get_metadata('published')) {
-    warn sprintf "WARNING: Skipping %s because 'published' flag is false\n" ,
-      $self->input_filename;
+    $self->LOGWARN(
+      sprintf "Skipping %s because 'published' flag is false" , $self->input_filename
+    );
     die;
   }
 }
@@ -46,28 +43,48 @@ sub get_default_layout { 'post' }
 sub publish {
   my $self = shift;
 
-  my( undef , $dir ) = fileparse( $self->output_filename );
+  my $out = path( $self->output_filename );
 
-  make_path $dir unless -d $dir;
+  my $dir = $out->parent;
+  $dir->mkpath unless $dir->is_dir;
 
-  open( my $out , '>:utf8' , $self->output_filename ) or die $!;
-  print $out $self->rendered_content;
-  close( $out );
+  $out->spew_utf8( $self->rendered_content );
 }
 
 # override
+my $date_regex = qr|([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})|;
+
+sub _build_basename {
+  my $self = shift;
+  my $ext = '.' . $self->ext;
+  my $basename = path( $self->input_filename )->basename( $ext );
+
+  if( $self->get_config( 'publish_drafts' )) {
+    if ( $self->is_draft ) {
+      # not fatal to lack a date if you're a draft, but okay to have one
+      $basename =~ s/^.*?$date_regex-//;
+      return $basename;
+    }
+  }
+
+  $basename =~ s/^.*?$date_regex-// or die "no date in filename";
+  return $basename;
+}
+
 sub _build_url {
   my $self = shift;
 
+  ### FIXME this is all horribly bigoted towards unix-ish file paths
   my %formats = (
     simple => '/posts/%{year}/%{month}/%{title}.html',
     date   => '/%{categories}s/%{year}s/%{month}s/%{day}s/%{title}s.html' ,
+    ii     => '%{year}s/%{month}s/%{day}s/%{title}s.html' ,
     pretty => '/%{categories}s/%{year}s/%{month}s/%{day}s/%{title}s/' ,
     none   => '/%{categories}s/%{title}s.html' ,
   );
 
-  ### FIXME need a way to get overall config in here...
-  my $permalink_format = $self->get_metadata( 'permalink' ) // 'date';
+  my $permalink_format = $self->get_metadata( 'permalink' ) //
+   $self->get_config('permalink') // 'date';
 
   $permalink_format = $formats{$permalink_format}
     if exists $formats{$permalink_format};
@@ -86,7 +103,6 @@ sub _build_url {
     year       => $self->year ,
   };
 
-  $permalink = "/$permalink";
   $permalink =~ s|//+|/|g;
 
   return $permalink;
@@ -99,7 +115,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -133,7 +149,7 @@ disk -- this data from this object.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -141,7 +157,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
