@@ -2,29 +2,23 @@
 
 
 package HiD::Role::IsConverted;
-{
-  $HiD::Role::IsConverted::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Role::IsConverted::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::Role::IsConverted::VERSION = '1.95_90';
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Carp;
-use Class::Load  qw/ :all /;
-use Encode;
-use File::Slurp  qw/ read_file /;
+use Class::Load  qw/ load_class /;
+use Path::Tiny;
+use YAML::XS     qw/ Load /; # YAML::Tiny doesn't support 'bool' types which we need 8^/
+
 use HiD::Types;
-use YAML::XS     qw/ Load /;
 
 requires 'get_default_layout';
 
@@ -59,9 +53,7 @@ has converted_excerpt => (
     if ( $self->excerpt ne $self->content ) {
       # Add the "read more" link
       ### FIXME this should be configurable
-      $converted_excerpt .= q{<p class="readmore"><a href="}
-        . $self->url
-          . q{" class="readmore">read more</a></p>};
+      $converted_excerpt .= $self->readmore_link;
     }
 
     return $converted_excerpt;
@@ -73,10 +65,10 @@ has hid => (
   is       => 'ro' ,
   isa      => 'HiD' ,
   required => 1 ,
+  handles  => [ qw/ get_config /] ,
 );
 
 
-
 has layouts => (
   is       => 'ro' ,
   isa      => 'HashRef[HiD::Layout]' ,
@@ -96,6 +88,28 @@ has metadata => (
 );
 
 
+has readmore_link => (
+  is      => 'ro' ,
+  isa     => 'Str' ,
+  lazy    => 1 ,
+  default => sub {
+    my $self = shift;
+
+    if ( defined $self->get_config('readmore_link')) {
+      my $link = $self->get_config('readmore_link');
+      my $url = $self->url;
+      $link =~ s/__URL__/$url/;
+      return $link;
+    };
+
+    return
+      q{<p class="readmore"><a href="}
+      . $self->url
+      . q{" class="readmore">read more</a></p>};
+  },
+);
+
+
 has rendered_content => (
   is      => 'ro' ,
   isa     => 'Str' ,
@@ -123,15 +137,14 @@ has template_data => (
     my $self = shift;
 
     my $data = {
+      baseurl  => $self->hid->config->{baseurl} ,
       content  => $self->converted_content ,
       page     => $self->metadata ,
       site     => $self->hid ,
     };
+    $data->{post} = $self if $self->does('HiD::Role::IsPost');
 
-    foreach my $method ( qw/ categories date tags title url / ) {
-      $data->{page}{$method} = $self->$method
-        if $self->can( $method );
-    }
+    $data->{page}{url} = $self->url if $self->can( 'url' );
 
     return $data;
   },
@@ -144,7 +157,7 @@ around BUILDARGS => sub {
   my %args = ( ref $_[0] and ref $_[0] eq 'HASH' ) ? %{ $_[0] } : @_;
 
   unless ( $args{content} and $args{metadata} ) {
-    my $file_content = read_file( $args{input_filename}, binmode => ':utf8' );
+    my $file_content = path( $args{input_filename} )->slurp_utf8;
 
     my( $metadata , $content );
     if ( $file_content =~ /^---/ ) {
@@ -160,7 +173,7 @@ around BUILDARGS => sub {
     }
 
     $args{content}  = $content;
-    $args{metadata} = Load( encode('utf8',$metadata) ) // {};
+    $args{metadata} = Load( $metadata ) // {};
   }
 
   return $class->$orig( \%args );
@@ -170,11 +183,12 @@ around BUILDARGS => sub {
 
   ### FIXME make this extensible
   my %conversion_extension_map = (
-    markdown => [ 'Text::Markdown' , 'markdown' ] ,
-    mkdn     => [ 'Text::Markdown' , 'markdown' ] ,
-    mk       => [ 'Text::Markdown' , 'markdown' ] ,
-    md       => [ 'Text::Markdown' , 'markdown' ] ,
-    textile  => [ 'Text::Textile'  , 'process'  ] ,
+    markdown => [ 'Text::Markdown'      , 'markdown' ] ,
+    mkdn     => [ 'Text::Markdown'      , 'markdown' ] ,
+    mk       => [ 'Text::Markdown'      , 'markdown' ] ,
+    md       => [ 'Text::Markdown'      , 'markdown' ] ,
+    mmd      => [ 'Text::MultiMarkdown' , 'markdown' ] ,
+    textile  => [ 'Text::Textile'       , 'process'  ] ,
   );
 
   sub _convert_by_extension {
@@ -198,7 +212,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -248,6 +262,14 @@ Hashref of layout objects keyed by name.
 
 Hashref of info from YAML front matter
 
+=head2 readmore_link
+
+Placed at the bottom of rendered excerpts. Intended to link to the full
+version of the content.
+
+A string matching C<__URL__> will be replaced with the URL of the object (i.e.,
+the output of C<$self->url>) being converted.
+
 =head2 rendered_content
 
 Content after any layouts have been applied
@@ -258,7 +280,7 @@ Data for passing to template processing function.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -266,7 +288,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
