@@ -2,38 +2,40 @@
 
 
 package HiD::Role::IsPost;
-{
-  $HiD::Role::IsPost::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Role::IsPost::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::Role::IsPost::VERSION = '1.95_90';
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use DateTime;
 use Date::Parse    qw/ str2time  /;
-use File::Basename qw/ fileparse /;
+
 use HiD::Types;
-use YAML::XS;
 
-my $date_regex = qr|([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})|;
 
-# override
-sub _build_basename {
+has author => (
+  is      => 'ro' ,
+  isa     => 'Str' ,
+  lazy    => 1 ,
+  builder => '_build_author' ,
+);
+
+sub _build_author {
   my $self = shift;
-  my $ext = '.' . $self->ext;
-  my $basename = fileparse( $self->input_filename , $ext );
-  $basename =~ s/^.*?$date_regex-// or die;
-  return $basename;
+
+  my $author = $self->get_metadata( 'author' );
+  return $author if defined $author;
+
+  my $default_author = $self->get_config( 'default_author' );
+  return $default_author if defined $default_author;
+
+  die "Need author for " . $self->basename . "\n"
 }
 
 
@@ -74,6 +76,10 @@ has date => (
   default => sub {
     my $self = shift;
 
+    if ( $self->get_config( 'publish_drafts' )){
+      return DateTime->now if $self->is_draft;
+    }
+
     my( $year , $month , $day );
     if ( my $date = $self->get_metadata( 'date' )) {
       return DateTime->from_epoch(
@@ -85,15 +91,25 @@ has date => (
       ( $year , $month , $day ) = $self->input_filename
         =~ m|^.*?/([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})-|;
       return DateTime->new(
-        year  => $year ,
-        month => $month ,
-        day   => $day
+        year      => $year ,
+        month     => $month ,
+        day       => $day ,
+        time_zone => 'UTC' ,
       );
     }
   },
 );
 
 
+has description => (
+  is      => 'ro' ,
+  isa     => 'Maybe[Str]' ,
+  lazy    => 1 ,
+  builder => '_build_description' ,
+);
+sub _build_description { shift->get_metadata( 'description' ) }
+
+
 has excerpt => (
   is      => 'ro',
   isa     => 'Str',
@@ -121,6 +137,8 @@ sub _build_excerpt {
 has tags => (
   is      => 'ro' ,
   isa     => 'ArrayRef',
+  traits  => [ qw/ Array / ] ,
+  handles => { join_tags => 'join' } ,
   default => sub {
     my $self = shift;
 
@@ -158,6 +176,22 @@ sub _build_title {
   return ( ref $title ) ? $$title : $title;
 }
 
+
+has twitter => (
+  is => 'ro' ,
+  isa => 'Maybe[Str]' ,
+  lazy => 1 ,
+  builder => '_build_twitter' ,
+);
+
+sub _build_twitter {
+  my $self = shift;
+
+  my $twitter = $self->get_metadata( 'twitter' );
+
+  return defined $twitter ? $twitter : undef;
+}
+
 around BUILDARGS => sub {
   my $orig  = shift;
   my $class = shift;
@@ -177,6 +211,19 @@ around BUILDARGS => sub {
   return $class->$orig( \%args );
 };
 
+
+sub all_tags { shift->join_tags(',') }
+
+
+my $drafts_dir;
+sub is_draft {
+  my $self = shift;
+
+  $drafts_dir //= $self->get_config( 'drafts_dir' );
+  return ( $self->input_filename =~ /^$drafts_dir/ ) ? 1 : 0;
+}
+
+
 no Moose::Role;
 1;
 
@@ -184,7 +231,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -207,12 +254,18 @@ post-specific attributes and methods.
 
 =head1 ATTRIBUTES
 
+=head2 author
+
 =head2 categories
 
 =head2 date
 
 DateTime object for this post.
 
+=head2 description
+
+A one-line synopsis of the post (used, e.g., for metadata information used by Open Graph)
+
 =head2 excerpt
 
 It is generally useful to summarize or lead a post with a "read more" tag
@@ -223,9 +276,22 @@ want to list the full post on the front page.
 
 =head2 title
 
+=head2 twitter
+
+=head1 METHODS
+
+=head2 all_tags
+
+Returns all tags for this post, joined together with commas
+
+=head2 is_draft
+
+Returns a boolean value indicating whether this post is coming from the drafts
+folder or not.
+
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -233,7 +299,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
