@@ -2,26 +2,20 @@
 
 
 package HiD::Role::IsPublished;
-{
-  $HiD::Role::IsPublished::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Role::IsPublished::AUTHORITY = 'cpan:GENEHACK';
-}
+$HiD::Role::IsPublished::VERSION = '1.95_90';
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename  qw/ fileparse /;
+use Path::Tiny;
+
 use HiD::Types;
-use Path::Class     qw/ file /;
 
 requires 'publish';
 
@@ -36,7 +30,7 @@ has basename => (
 sub _build_basename {
   my $self = shift;
   my $ext = '.' . $self->ext;
-  return fileparse( $self->input_filename , $ext );
+  return path( $self->input_filename )->basename( $ext );
 }
 
 
@@ -50,11 +44,8 @@ has baseurl => (
 sub _build_baseurl {
   my $self = shift;
 
-  my $base_url = $self->config->{baseurl};
-  if( defined $base_url ) {
-    return $base_url;
-  }
-  return '/';
+  my $base_url = $self->get_config('baseurl');
+  return defined $base_url ? $base_url : '/';
 }
 
 
@@ -88,11 +79,7 @@ has input_path => (
   is      => 'ro' ,
   isa     => 'HiD_DirPath' ,
   lazy    => 1 ,
-  default => sub {
-    my $self = shift;
-    my( undef , $path ) = fileparse( $self->input_filename );
-    return $path;
-  },
+  default => sub { path( shift->input_filename )->parent->stringify() },
 );
 
 
@@ -106,7 +93,7 @@ has output_filename => (
     my $url = $self->url;
     $url .= 'index.html' if $url =~ m|/$|;
 
-    return file( $self->dest_dir , $url )->stringify;
+    return path( $self->dest_dir , $url )->stringify;
   },
 );
 
@@ -132,7 +119,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -194,7 +181,7 @@ The URL to the output path for the written file.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -202,7 +189,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
