@@ -2,22 +2,14 @@
 
 
 package HiD::Types;
-{
-  $HiD::Types::VERSION = '1.0';
-}
-BEGIN {
-  $HiD::Types::AUTHORITY = 'cpan:GENEHACK';
-}
-
-use 5.014;
+$HiD::Types::VERSION = '1.95_90';
+use 5.014; # strict, unicode_strings
 use utf8;
-use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Moose::Util::TypeConstraints;
 
@@ -40,6 +32,20 @@ subtype 'HiD_PosInt'
   => where { $_ > 0 }
   => message { "Must be positive integer." };
 
+class_type 'HiD_Post' , { class => 'HiD::Post' };
+
+### FIXME delete if after 13 Nov 2014
+class_type 'deprecated_HiD_Plugin_class' , { class => 'HiD::Plugin'};
+
+role_type 'HiD_Plugin'    , { role => 'HiD::Plugin'};
+role_type 'HiD_Generator' , { role => 'HiD::Generator'};
+
+union 'Pluginish' , [qw/
+                         deprecated_HiD_Plugin_class
+                         HiD_Plugin
+                         HiD_Generator
+                       / ];
+
 no Moose::Util::TypeConstraints;
 1;
 
@@ -47,7 +53,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -59,7 +65,7 @@ Type constraints for HiD.
 
 =head1 VERSION
 
-version 1.0
+version 1.95_90
 
 =head1 AUTHOR
 
@@ -67,7 +73,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
